==> estateplat-common-1.2.4-20191212.063146-213-sources.jar: cn/gtmap/estateplat/model/server/core/BdcBdcdySd.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * .
 * <p/>
 * 不动产单元表锁定表
 *
 * @author zq
 * @version V1.0, 15-3-12
 */
@Table(name = "bdc_bdcdysd")
public class BdcBdcdySd implements Serializable, InsertVo {
    @Id
    private String bdcdyid;//不动产单元id
    private String bdcdyh;//不动产单元号
    private String zl;//坐落
    private String bdclx;//不动产类型
    private String qlr;//宗地宗海用途
    private String xzzt;//限制状态  0正常 1锁定
    private String xzyy;//限制原因
    private String xztype;//限制类型 有其他限制可以存到此表
	private String sdr;//锁定人
	private Date sdsj;//锁定时间
	private String jsr;//解锁人
	private Date jssj;//解锁时间
	private String proid;//项目id
	private String wiid;//工作流id
	private String bh;//受理编号
    private String jslcgzlid;//解锁流程工作流ID
    private String sdjg;//锁定结构
    private String sdwh;//锁定文号
    private String jsjg;//解锁机构
    private String jswh;//解锁文号

    public String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getXzzt() {
        return xzzt;
    }

    public void setXzzt(String xzzt) {
        this.xzzt = xzzt;
    }

    public String getXzyy() {
        return xzyy;
    }

    public void setXzyy(String xzyy) {
        this.xzyy = xzyy;
    }

    public String getXztype() {
        return xztype;
    }

    public void setXztype(String xztype) {
        this.xztype = xztype;
    }

	public String getSdr() {
		return sdr;
	}

	public void setSdr(String sdr) {
		this.sdr = sdr;
	}

	public Date getSdsj() {
		return sdsj;
	}

	public void setSdsj(Date sdsj) {
		this.sdsj = sdsj;
	}

	public String getJsr() {
		return jsr;
	}

	public void setJsr(String jsr) {
		this.jsr = jsr;
	}

	public Date getJssj() {
		return jssj;
	}

	public void setJssj(Date jssj) {
		this.jssj = jssj;
	}

	public String getProid() {
		return proid;
	}

	public void setProid(String proid) {
		this.proid = proid;
	}

	public String getWiid() {
		return wiid;
	}

	public void setWiid(String wiid) {
		this.wiid = wiid;
	}

    public String getBh() {
        return bh;
    }

    public void setBh(String bh) {
        this.bh = bh;
    }

    public String getJslcgzlid() {
        return jslcgzlid;
    }

    public void setJslcgzlid(String jslcgzlid) {
        this.jslcgzlid = jslcgzlid;
    }

    public String getSdjg() {
        return sdjg;
    }

    public void setSdjg(String sdjg) {
        this.sdjg = sdjg;
    }

    public String getSdwh() {
        return sdwh;
    }

    public void setSdwh(String sdwh) {
        this.sdwh = sdwh;
    }

    public String getJsjg() {
        return jsjg;
    }

    public void setJsjg(String jsjg) {
        this.jsjg = jsjg;
    }

    public String getJswh() {
        return jswh;
    }

    public void setJswh(String jswh) {
        this.jswh = jswh;
    }
}

==> estateplat-common-1.2.4-20250714.071418-1304-sources.jar: cn/gtmap/estateplat/model/server/core/BdcBdcdySd.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Id;
import javax.persistence.Table;
import java.io.Serializable;
import java.util.Date;

/**
 * 
 * 不动产单元表锁定表
 *
 * @author zq
 * @version V1.0, 15-3-12
 */
@Table(name = "bdc_bdcdysd")
public class BdcBdcdySd implements Serializable, InsertVo {
    @Id
    private String bdcdyid;//不动产单元id
    private String bdcdyh;//不动产单元号
    private String zl;//坐落
    private String bdclx;//不动产类型
    private String qlr;//宗地宗海用途
    private String xzzt;//限制状态  0正常 1锁定
    private String xzyy;//限制原因
    private String xztype;//限制类型 有其他限制可以存到此表
	private String sdr;//锁定人
	private Date sdsj;//锁定时间
	private String jsr;//解锁人
	private Date jssj;//解锁时间
	private String proid;//项目id
	private String wiid;//工作流id
	private String bh;//受理编号
    private String jslcgzlid;//解锁流程工作流ID
    private String sdjg;//锁定结构
    private String sdwh;//锁定文号
    private String jsjg;//解锁机构
    private String jswh;//解锁文号
    private Date xzkssj;//限制开始时间
    private Date xzjssj;//限制结束时间

    public Date getXzkssj() {
        return xzkssj;
    }

    public void setXzkssj(Date xzkssj) {
        this.xzkssj = xzkssj;
    }

    public Date getXzjssj() {
        return xzjssj;
    }

    public void setXzjssj(Date xzjssj) {
        this.xzjssj = xzjssj;
    }

    public String getBdcdyid() {
        return bdcdyid;
    }

    public void setBdcdyid(String bdcdyid) {
        this.bdcdyid = bdcdyid;
    }

    public String getBdcdyh() {
        return bdcdyh;
    }

    public void setBdcdyh(String bdcdyh) {
        this.bdcdyh = bdcdyh;
    }

    public String getZl() {
        return zl;
    }

    public void setZl(String zl) {
        this.zl = zl;
    }

    public String getBdclx() {
        return bdclx;
    }

    public void setBdclx(String bdclx) {
        this.bdclx = bdclx;
    }

    public String getQlr() {
        return qlr;
    }

    public void setQlr(String qlr) {
        this.qlr = qlr;
    }

    public String getXzzt() {
        return xzzt;
    }

    public void setXzzt(String xzzt) {
        this.xzzt = xzzt;
    }

    public String getXzyy() {
        return xzyy;
    }

    public void setXzyy(String xzyy) {
        this.xzyy = xzyy;
    }

    public String getXztype() {
        return xztype;
    }

    public void setXztype(String xztype) {
        this.xztype = xztype;
    }

	public String getSdr() {
		return sdr;
	}

	public void setSdr(String sdr) {
		this.sdr = sdr;
	}

	public Date getSdsj() {
		return sdsj;
	}

	public void setSdsj(Date sdsj) {
		this.sdsj = sdsj;
	}

	public String getJsr() {
		return jsr;
	}

	public void setJsr(String jsr) {
		this.jsr = jsr;
	}

	public Date getJssj() {
		return jssj;
	}

	public void setJssj(Date jssj) {
		this.jssj = jssj;
	}

	public String getProid() {
		return proid;
	}

	public void setProid(String proid) {
		this.proid = proid;
	}

	public String getWiid() {
		return wiid;
	}

	public void setWiid(String wiid) {
		this.wiid = wiid;
	}

    public String getBh() {
        return bh;
    }

    public void setBh(String bh) {
        this.bh = bh;
    }

    public String getJslcgzlid() {
        return jslcgzlid;
    }

    public void setJslcgzlid(String jslcgzlid) {
        this.jslcgzlid = jslcgzlid;
    }

    public String getSdjg() {
        return sdjg;
    }

    public void setSdjg(String sdjg) {
        this.sdjg = sdjg;
    }

    public String getSdwh() {
        return sdwh;
    }

    public void setSdwh(String sdwh) {
        this.sdwh = sdwh;
    }

    public String getJsjg() {
        return jsjg;
    }

    public void setJsjg(String jsjg) {
        this.jsjg = jsjg;
    }

    public String getJswh() {
        return jswh;
    }

    public void setJswh(String jswh) {
        this.jswh = jswh;
    }
}
